========
Cnc 2.5D
========

Cnc25D is a Python_ Package for 2.5D part design and cuboid assembly.

.. _Python : http://www.python.org

* Cnc25D relies on FreeCAD_
* Cnc25D helps create FreeCAD_ macro
* Cnc25D helps design 3D parts entirely with Python_ script
* Cnc25D provides parametric ready-to-use design examples
* Cnc25D helps drawing shape makable by a 3-axis CNC
* Cnc25D helps positioning parts in a cuboid assembly

Have a look at the `Cnc25D documentation`_ for more information.

The source code is available at https://github.com/charlyoleg/Cnc25D

.. _FreeCAD : http://www.freecadweb.org

.. _`Cnc25D documentation` : 


Why 2.5D ?
----------

3-axis CNC, laser cutter and water jet machine are getting cheaper and can be used in fablab, makerspace or hackerspace. 3-axis machine lets make 2.5D design, i.e. free xy-path at z constant. 

Installation
------------

Cnc25D is on PyPI_.

To install Cnc25D:

* First, install FreeCAD_
* Second, run the following commands::

  > sudo pip install Cnc25D -U
  > cd directory/where/I/want/to/create/my/3D/parts
  > cnc25d_example_generator.py

.. _PyPI : 



Feedback / Contact
------------------

If you find bugs, suggest fix or want new features send me an email or clone the `Cnc25D GitHub repository`_.

Send a message to "charlyoleg at fabfolk dot com" for any requests and feedback!

.. _`Cnc25D GitHub repository` : https://github.com/charlyoleg/Cnc25D



